@@ -13,11 +13,8 @@ class simple_ml():
     def __init__(self, X, y):
         self.X = X
         self.y = y
-        self.clf = None
         
     def train(self, clf, standardize = False):
-        self.clf = clf
-        
         X_train, X_test, y_train, y_test = train_test_split(self.X, self.y, test_size = 0.2)
         
         self.standardize = standardize
